@@ -17,8 +17,13 @@ from vyomcloudbridge.utils.common import get_file_info, parse_bool
 from vyomcloudbridge.utils.logger_setup import setup_logger
 from vyomcloudbridge.utils.configs import Configs
 from vyomcloudbridge.constants.constants import MAX_FILE_SIZE
-from vyomcloudbridge.utils.common import get_mission_upload_dir, get_data_upload_dir
+from vyomcloudbridge.utils.common import (
+    get_mission_upload_dir,
+    get_data_upload_dir,
+    default_dir_data_source,
+)
 from vyomcloudbridge.constants.constants import data_buffer_key
+import traceback
 
 # logger = setup_logger(name=__name__, show_terminal=False)
 
@@ -34,7 +39,7 @@ class DirWatcher:
             Dict, str
         ] = {},  # Properties for the directory or path to a JSON file
         merge_chunks: bool = False,
-        priority: Number = 1,
+        priority: int = 1,
         preserve_file: bool = False,  # this we will implement
     ):
         """
@@ -130,7 +135,7 @@ class DirWatcher:
     #         rel_path_dir = ""
     #     elif rel_path_dir:
     #         rel_path_dir = "/" + rel_path_dir
-    #     return f"{self.machine_config['organization_id']}/_uploads_/{date}/{self.machine_config['machine_id']}{rel_path_dir}"
+    #     return f"{self.machine_config['organization_id']}/_uploads_/{self.machine_config['machine_id']}{rel_path_dir}"
 
     def _setup_signal_handlers(self):
         """Setup signal handlers for graceful shutdown."""
@@ -241,12 +246,12 @@ class DirWatcher:
                         project_id=project_id,
                     )
                     filename, file_extension, data_type, file_size = get_file_info(
-                        filepath
+                        str(filepath)
                     )
-                    file_dir: str = mission_upload_dir
-                    chunk_dir: str = mission_upload_dir + f"/chunk"
+                    file_dir = mission_upload_dir
+                    chunk_dir = mission_upload_dir + f"/chunk"
                     queue_writer_client.write_from_file(
-                        filepath,
+                        str(filepath),
                         properties,
                         data_source=data_source,
                         file_dir=file_dir,
@@ -271,7 +276,7 @@ class DirWatcher:
             else:
                 if len(path_parts) <= 3:
                     filename, file_extension, data_type, file_size = get_file_info(
-                        filepath
+                        str(filepath)
                     )
                     # data_upload_dir = self._data_upload_dir(filepath) # TODO PATH
                     rel_filepath = filepath.relative_to(self.watch_dir)
@@ -285,9 +290,9 @@ class DirWatcher:
                     file_dir: str = data_upload_dir
                     chunk_dir: str = data_upload_dir + f"/chunk"
                     queue_writer_client.write_from_file(
-                        filepath,
+                        str(filepath),
                         self.properties,
-                        data_source=data_source,
+                        data_source=default_dir_data_source,
                         file_dir=file_dir,
                         chunk_dir=chunk_dir,
                         merge_chunks=self.merge_chunks,
@@ -486,6 +491,7 @@ class DirWatcher:
         """
         return (
             self.is_running
+            and self.queue_writer_client
             and self.queue_writer_client.is_healthy()
             and self.mission_stats.is_healthy()
         )
@@ -518,7 +524,8 @@ def main():
                 print("\nInterrupted by user, shutting down...")
                 break
     except Exception as e:
-        print(f"Error in main thread: {str(e)}", exc_info=True)
+        print(f"Error in main thread: {str(e)}")
+        traceback.print_exc()
     finally:
         print("Cleaning up resources")
         dir_watcher.stop()
