@@ -21,19 +21,19 @@ logger.addHandler(stream_handler)
 class MqttServerClient:
     def __init__(
         self,
-        broker_host: str = "3.110.9.183",
-        broker_port: int = 8883,
+        host: str = "3.110.9.183",
+        port: int = 8883,
         username: str = "vyom_iq",
         password: str = "vyomiqpassword",
         callback: Callable = None,
         client_id_prefix: str = "server"
     ):
         try:
-            self.broker_host = broker_host
-            self.broker_port = broker_port
+            self.host = host
+            self.port = port
             self.username = username
             self.password = password
-            self.callback = callback
+            self.message_callback = callback
             self.client_id = f"{client_id_prefix}_{uuid.uuid4().hex[:8]}"
 
             # Connection state tracking
@@ -47,10 +47,10 @@ class MqttServerClient:
             # Connection and reconnection parameters
             self.max_reconnect_attempts = 5
             self.base_reconnect_delay = 1
-            self.reconnect_delay_max = 60
+            self.max_reconnect_delay = 60
 
             # Initialize MQTT client
-            self.mqtt_client = None
+            self.mqtt_connection = None
             self._create_mqtt_client()
 
             # Start connection monitoring
@@ -64,7 +64,7 @@ class MqttServerClient:
         """Create and configure MQTT client"""
         try:
             # Create MQTT client
-            self.mqtt_client = mqtt.Client(
+            self.mqtt_connection = mqtt.Client(
                 client_id=self.client_id,
                 clean_session=False,
                 protocol=mqtt.MQTTv311
@@ -72,19 +72,19 @@ class MqttServerClient:
 
             # Set username and password if provided
             if self.username and self.password:
-                self.mqtt_client.username_pw_set(self.username, self.password)
+                self.mqtt_connection.username_pw_set(self.username, self.password)
 
             # Set callbacks
-            self.mqtt_client.on_connect = self._on_connect
-            self.mqtt_client.on_disconnect = self._on_disconnect
-            self.mqtt_client.on_message = self._message_callback
-            self.mqtt_client.on_subscribe = self._on_subscribe
-            self.mqtt_client.on_publish = self._on_publish
-            self.mqtt_client.on_log = self._on_log
+            self.mqtt_connection.on_connect = self._on_connection_resumed
+            self.mqtt_connection.on_disconnect = self._on_connection_interrupted
+            self.mqtt_connection.on_message = self._message_callback
+            self.mqtt_connection.on_subscribe = self._on_subscribe
+            self.mqtt_connection.on_publish = self._on_publish
+            self.mqtt_connection.on_log = self._on_log
 
             # Configure client options
-            self.mqtt_client.max_inflight_messages_set(100)
-            self.mqtt_client.max_queued_messages_set(1000)
+            self.mqtt_connection.max_inflight_messages_set(100)
+            self.mqtt_connection.max_queued_messages_set(1000)
 
             logger.info("MQTT server client created successfully")
 
@@ -92,10 +92,10 @@ class MqttServerClient:
             logger.error(f"Failed to create MQTT client: {str(e)}")
             raise
 
-    def _on_connect(self, client, userdata, flags, rc):
+    def _on_connection_resumed(self, client, userdata, flags, rc):
         """Callback for when client connects to broker"""
         if rc == 0:
-            logger.info(f"Server client connected successfully to {self.broker_host}:{self.broker_port}")
+            logger.info(f"Server client connected successfully to {self.host}:{self.port}")
             with self.connection_lock:
                 self.is_connected = True
                 self._connection_in_progress = False
@@ -115,7 +115,7 @@ class MqttServerClient:
                 self.is_connected = False
                 self._connection_in_progress = False
 
-    def _on_disconnect(self, client, userdata, rc):
+    def _on_connection_interrupted(self, client, userdata, rc):
         """Callback for when client disconnects from broker"""
         if rc != 0:
             logger.warning(f"Server client disconnected unexpectedly, return code: {rc}")
@@ -133,8 +133,8 @@ class MqttServerClient:
             payload = msg.payload.decode('utf-8')
             logger.info(f"Received message from topic '{topic}': {payload}")
             
-            if self.callback:
-                self.callback(topic, payload)
+            if self.message_callback:
+                self.message_callback(topic, payload)
             else:
                 logger.debug("No callback provided, skipping callback execution")
                 
@@ -169,15 +169,15 @@ class MqttServerClient:
         try:
             for attempt in range(self.max_reconnect_attempts):
                 try:
-                    delay = min(self.base_reconnect_delay * (2 ** attempt), self.reconnect_delay_max)
+                    delay = min(self.base_reconnect_delay * (2 ** attempt), self.max_reconnect_delay)
                     
                     if attempt > 0:
                         logger.info(f"Reconnection attempt {attempt + 1}/{self.max_reconnect_attempts}")
                         time.sleep(delay)
 
                     # Connect to broker
-                    self.mqtt_client.connect(self.broker_host, self.broker_port, 60)
-                    self.mqtt_client.loop_start()
+                    self.mqtt_connection.connect(self.host, self.port, 60)
+                    self.mqtt_connection.loop_start()
                     
                     # Wait for connection
                     timeout = 10
@@ -205,7 +205,7 @@ class MqttServerClient:
         """Resubscribe to all previously subscribed topics"""
         for topic in self.subscribed_topics.copy():
             try:
-                result = self.mqtt_client.subscribe(topic, qos=1)
+                result = self.mqtt_connection.subscribe(topic, qos=1)
                 if result[0] == mqtt.MQTT_ERR_SUCCESS:
                     logger.info(f"Resubscribed to topic: {topic}")
                 else:
@@ -220,7 +220,7 @@ class MqttServerClient:
                 if not self.connect():
                     raise ConnectionError("Failed to connect to MQTT broker")
 
-            result = self.mqtt_client.subscribe(topic, qos=qos)
+            result = self.mqtt_connection.subscribe(topic, qos=qos)
             if result[0] == mqtt.MQTT_ERR_SUCCESS:
                 self.subscribed_topics.add(topic)
                 logger.info(f"Subscribed to topic: {topic} with QoS: {qos}")
@@ -245,7 +245,7 @@ class MqttServerClient:
             # Convert to format expected by paho-mqtt
             topic_list = [(topic, qos) for topic, qos in topics]
             
-            result = self.mqtt_client.subscribe(topic_list)
+            result = self.mqtt_connection.subscribe(topic_list)
             if result[0] == mqtt.MQTT_ERR_SUCCESS:
                 for topic, qos in topics:
                     self.subscribed_topics.add(topic)
@@ -271,7 +271,7 @@ class MqttServerClient:
                 payload = json.dumps(payload)
 
             logger.info(f"Publishing message to topic: {topic}")
-            result = self.mqtt_client.publish(topic, payload, qos=qos, retain=retain)
+            result = self.mqtt_connection.publish(topic, payload, qos=qos, retain=retain)
             
             if result.rc == mqtt.MQTT_ERR_SUCCESS:
                 logger.info(f"Message published successfully to topic: {topic}")
@@ -319,7 +319,7 @@ class MqttServerClient:
                 logger.warning("Not connected to broker")
                 return False
 
-            result = self.mqtt_client.unsubscribe(topic)
+            result = self.mqtt_connection.unsubscribe(topic)
             if result[0] == mqtt.MQTT_ERR_SUCCESS:
                 self.subscribed_topics.discard(topic)
                 logger.info(f"Unsubscribed from topic: {topic}")
@@ -336,8 +336,8 @@ class MqttServerClient:
         """Get current connection status and statistics"""
         return {
             "is_connected": self.is_connected,
-            "broker_host": self.broker_host,
-            "broker_port": self.broker_port,
+            "host": self.host,
+            "port": self.port,
             "client_id": self.client_id,
             "subscribed_topics": list(self.subscribed_topics),
             "topic_count": len(self.subscribed_topics)
@@ -362,9 +362,9 @@ class MqttServerClient:
     def disconnect(self):
         """Gracefully disconnect from MQTT broker"""
         try:
-            if self.mqtt_client:
-                self.mqtt_client.loop_stop()
-                self.mqtt_client.disconnect()
+            if self.mqtt_connection:
+                self.mqtt_connection.loop_stop()
+                self.mqtt_connection.disconnect()
                 
             with self.connection_lock:
                 self.is_connected = False
@@ -421,8 +421,8 @@ def main():
     try:
         # Connect to AWS IoT Core
         client = MqttServerClient(
-            broker_host="3.110.9.183",  # Change to your EC2 instance IP for remote access
-            broker_port=8883,
+            host="3.110.9.183",  # Change to your EC2 instance IP for remote access
+            port=8883,
             username="vyom_iq",  # Uncomment if authentication is enabled
             password="vyomiqpassword",  # Uncomment if authentication is enabled
             callback=message_callback,
