@@ -13,13 +13,14 @@ from pika.exceptions import (
     AMQPConnectionError,
 )
 from concurrent.futures import ThreadPoolExecutor
-from typing import Callable, Dict, Any
+from typing import Callable, Dict, Any, Tuple
 from vyomcloudbridge.services.vyom_sender import VyomSender
 from vyomcloudbridge.utils.common import ServiceAbstract, parse_bool
 from vyomcloudbridge.utils.configs import Configs
 from vyomcloudbridge.services.mission_stats import MissionStats
 from vyomcloudbridge.constants.constants import data_buffer_key
 from vyomcloudbridge.utils.logger_setup import setup_logger
+from vyomcloudbridge.constants.constants import main_data_queue
 
 
 class QueueWorker(ServiceAbstract):
@@ -40,11 +41,11 @@ class QueueWorker(ServiceAbstract):
             self.logger.info("QueueWorker initialized successfully!")
             self.upload_stats = {}
             self._upload_stats_lock = threading.Lock()
-            self.upload_stats_publish_interval = 120
+            self.upload_stats_publish_interval = 10 # TODO is was 120 earlier
             self.upload_stats_error_delay = 300
 
             self.host = host
-            self.queue_name = "data_queue"
+            self.queue_name = main_data_queue
             self.num_threads = num_threads if parse_bool(multi_thread) else 1
             self.is_running = False
 
@@ -69,7 +70,7 @@ class QueueWorker(ServiceAbstract):
                     )
                     raise
 
-    def proccess_deque_message(self, message: Dict[str, Any], vyom_sender_conn) -> bool:
+    def proccess_deque_message(self, message: Dict[str, Any], vyom_sender_conn) -> Tuple[bool, list[Any]]:
         """
         Args:
             message (Dict[str, Any]): The message to be processed.
@@ -253,7 +254,7 @@ class QueueWorker(ServiceAbstract):
                 #     new_properties["expiration"] = properties.expiration
 
                 if hasattr(properties, "headers") and properties.headers:
-                    headers = copy.deepcopy(properties.headers)
+                    headers = dict(copy.deepcopy(properties.headers))
                     headers["destination_ids"] = remaining_dest_ids
                     new_properties["headers"] = headers
 
@@ -371,7 +372,7 @@ class QueueWorker(ServiceAbstract):
             self.logger.info(f"Worker thread started for {self.queue_name}")
             while self.is_running:
                 # Process messages for a short time before checking if we should stop
-                rmq_conn.process_data_events(time_limit=1.0)
+                rmq_conn.process_data_events(time_limit=1)
 
         except (ConnectionClosedByBroker, AMQPChannelError) as e:
             self.logger.error(f"Connection error in worker: {e}")
@@ -381,7 +382,6 @@ class QueueWorker(ServiceAbstract):
             if rmq_channel is not None and rmq_channel.is_open:
                 try:
                     rmq_channel.close()
-                    vyom_sender_conn.cleanup()
                 except:
                     pass
 
