@@ -98,7 +98,7 @@ class RootStore(ServiceAbstract):  # Not in use
         Args:
             key: The queue name to ensure exists
         """
-        if not self._ensure_connection():
+        if not self._ensure_connection() or not self.rmq_channel:
             raise Exception("Could not establish connection")
 
         self._validate_key(key)
@@ -126,7 +126,7 @@ class RootStore(ServiceAbstract):  # Not in use
             data: Any JSON serializable data to store (dict, list, int, str, etc.)
         """
         try:
-            if not self._ensure_connection():
+            if not self._ensure_connection() or not self.rmq_channel:
                 raise Exception("Could not establish connection")
 
             self.logger.info(f"Setting data for key {key}")
@@ -184,7 +184,7 @@ class RootStore(ServiceAbstract):  # Not in use
             Data (any type) or None if not found
         """
         try:
-            if not self._ensure_connection():
+            if not self._ensure_connection() or not self.rmq_channel:
                 raise Exception("Could not establish connection")
 
             self._validate_key(key)
@@ -232,7 +232,7 @@ class RootStore(ServiceAbstract):  # Not in use
             data: Any JSON serializable data to store (dict, list, int, str, etc.)
         """
         try:
-            if not self._ensure_connection():
+            if not self._ensure_connection() or not self.rmq_channel:
                 raise Exception("Could not establish connection")
 
             self.logger.info(f"updating data for key {key}")
@@ -287,7 +287,7 @@ class RootStore(ServiceAbstract):  # Not in use
             key: The queue name to delete data from
         """
         try:
-            if not self._ensure_connection():
+            if not self._ensure_connection() or not self.rmq_channel:
                 raise Exception("Could not establish connection")
 
             self._validate_key(key)
@@ -819,7 +819,7 @@ def main():
         retrieved_user = get_data(user_key)
         print(f"Retrieved user_data 3: {retrieved_user}")
 
-        # location = {"lat": 76.987934, "long": 76.937954, "timestamp": "93u4983"}
+        # location = {"lat": 76.987934, "long": 76.937954, "alt": 930, "timestamp": "93u4983"}
         # health = {"status": 1 or 0, "message": ""}
         # store.set_data("location", location)
         # store.set_data("health", health)
