@@ -1,4 +1,3 @@
-# utils/send_data_to_server.py
 # === Standard Library ===
 import importlib
 import json
@@ -29,6 +28,7 @@ from vyomcloudbridge.services.queue_writer_json import QueueWriterJson
 from vyomcloudbridge.utils.common import ServiceAbstract
 from vyomcloudbridge.utils.logger_setup import setup_logger
 import vyomcloudbridge.utils.converter as converter
+from vyomcloudbridge.utils.throttle_utils import should_throttle
 
 
 class SendDataToServer(Node, ServiceAbstract):
@@ -86,6 +86,7 @@ class SendDataToServer(Node, ServiceAbstract):
             String, "update_topic_list", self.update_topic_list_callback, 10
         )
         self.topic_list_sub
+        self._freq_tracker = defaultdict(lambda: {"last_time": None})
 
     def update_topic_list_callback(self, msg):
         # Get new topic list
@@ -132,9 +133,7 @@ class SendDataToServer(Node, ServiceAbstract):
         only those topics that are marked as subscribed.
 
         Returns:
-            list: A list of dictionaries representing the subscribed topics. Each
-            dictionary contains topic details, including an "is_subscribed" key
-            indicating subscription status.
+            list: A list of dictionaries representing the subscribed topics.
         """
 
         topic_list = self.load_topic_list_from_file()
@@ -172,14 +171,14 @@ class SendDataToServer(Node, ServiceAbstract):
         self.logger.debug(f"Summary {summary}")
 
         self.writer.write_message(
-            message_data={"mission_summary": summary},
+            message_data=summary,
             data_type="json",
-            data_source="mission_stats",
+            data_source="mission_summary",
             destination_ids=["s3", "gcs_mqtt"],
             filename=None,
             mission_id=self.current_mission.get("id"),
             project_id=None,
-            priority=1,
+            priority=3,
             merge_chunks=True,
             send_live=True,
         )
@@ -190,14 +189,12 @@ class SendDataToServer(Node, ServiceAbstract):
         if self.current_mission is None:
             return default_mission_id
         self.logger.debug(f"self.current_mission: {self.current_mission}")
-        if self.current_mission.get("mission_status") == 1:  # live
-            self.logger.debug("started")
 
+        if self.current_mission.get("mission_status") == 1:
             self.summariser.set_mission_mode(1)
             return self.current_mission.get("id") or default_mission_id
 
         if self.current_mission.get("mission_status") == 2:
-
             if self.summariser.get_mission_mode() == 1:
                 self.logger.debug("stopped")
                 self.summariser.print_summary()
@@ -207,18 +204,10 @@ class SendDataToServer(Node, ServiceAbstract):
 
         return default_mission_id
 
-    def create_listener_function(self, msg_data_type, f_topic_name, f_topic):
+    def create_listener_function(self, f_msg_data_type, f_topic_name, f_topic, f_send_live, f_data_upload_frequency, f_save_locally):
         """
         Creates a listener function for processing incoming messages of a specific type and topic.
 
-        Args:
-            msg_type (type): The type of the message to be processed (e.g., sensor_msgs.msg.Image).
-            f_topic (str): The topic associated with the message.
-
-        Returns:
-            function: A listener function that processes incoming messages, extracts relevant data,
-                      and writes the data to a specified destination.
-
         The generated listener function performs the following:
             - Converts the incoming message to the desired format using a converter.
             - Extracts a timestamp from the message header if available.
@@ -227,73 +216,88 @@ class SendDataToServer(Node, ServiceAbstract):
             - Prepares the extracted data for writing, including metadata such as timestamp,
               topic, mission ID, and the converted data.
             - Writes the processed data to a destination using the `self.writer.write_message` method.
-
-        Notes:
-            - If the message type is `sensor_msgs.msg.Image`, the data is treated as an image and saved
-              with a `.jpeg` extension.
-            - If the message does not contain a timestamp, a placeholder value of 0 is used for both
-              seconds and nanoseconds.
-            - The `self.mission_id` attribute is used to associate the data with a specific mission.
-            - The `self.writer.write_message` method handles the actual writing of the processed data.
         """
 
-        # eg: msg_data_type=vyom_mission_msgs.msg.MissionStatus, f_topic_name=MISSION_TOPIC
-        def f(msg):
+        # eg: f_msg_data_type=vyom_mission_msgs.msg.MissionStatus, f_topic_name=MISSION_TOPIC
+        def callback(msg):
             self.summariser.update(f_topic, msg)
 
             self.logger.debug(f"Ros data processing for ros_topic: {f_topic_name}")
 
-            current_value = converter.convert(msg_data_type, 1, msg)
+            tracker = self._freq_tracker[f_topic_name]
+            now = self._clock.now().nanoseconds / 1e9
+            should_log, upload_freq, msg_freq = should_throttle(tracker, f_data_upload_frequency, now)
+            
+            if should_log:
+                self.logger.info(
+                    f"[{f_topic_name}] Msg Freq: {msg_freq:.2f} Hz | "
+                    f"Upload Freq: {upload_freq:.2f} Hz | Msg: {msg}"
+                )
 
-            cleaned_value = self.replace_nan_with_null(current_value)
+                current_value = converter.convert(f_msg_data_type, 1, msg)
 
-            now = time.time()
-            epoch_ms = int(now * 1000)
+                cleaned_value = self.replace_nan_with_null(current_value)
 
-            if msg_data_type == "sensor_msgs.msg.Image":
-                filename = f"{epoch_ms}.jpeg"
-                data_type = "image"
-                extracted_data = cleaned_value
-            else:
-                filename = f"{epoch_ms}.json"
-                data_type = "json"
+                now = time.time()
+                epoch_ms = int(now * 1000)
 
-                timestamp_sec = int(now)
-                timestamp_nsec = int((now - timestamp_sec) * 1_000_000_000)
+                if f_msg_data_type == "sensor_msgs.msg.Image":
+                    filename = f"{epoch_ms}.jpeg"
+                    data_type = "image"
+                    extracted_data = cleaned_value
+                else:
+                    filename = f"{epoch_ms}.json"
+                    data_type = "json"
 
-                extracted_data = {
-                    "timestamp": {
-                        "seconds": timestamp_sec,
-                        "nanoseconds": timestamp_nsec,
-                    },
-                    "key": f_topic_name,
-                    "mission_id": self.mission_id,
-                    "data": {},
-                }
-                extracted_data["data"] = cleaned_value
+                    timestamp_sec = int(now)
+                    timestamp_nsec = int((now - timestamp_sec) * 1_000_000_000)
 
-            self.logger.debug(
-                f"Logs data type: {type(cleaned_value)}, filename: {filename}, data_type: {data_type} epoch_ms"
-            )
+                    extracted_data = {
+                        "timestamp": {
+                            "seconds": timestamp_sec,
+                            "nanoseconds": timestamp_nsec,
+                        },
+                        "key": f_topic_name,
+                        "mission_id": self.mission_id,
+                        "data": {},
+                    }
+                    extracted_data["data"] = cleaned_value
 
-            # Get mission id
-            self.mission_id = self.update_mission_id()
-            self.logger.info(f"self.mission_id: {self.mission_id}")
+                self.logger.debug(
+                    f"Logs data type: {type(cleaned_value)}, filename: {filename}, data_type: {data_type} epoch_ms"
+                )
 
-            self.writer.write_message(
-                message_data=extracted_data,  # json data
-                filename=filename,  # nullable or epoch time
-                data_source=f_topic_name,  # telemetry, mission_summary
-                data_type=data_type,  # file, video, image
-                mission_id=self.mission_id,  # mission_id
-                priority=1,  # 1  for velocity data, battery topic, and ROS data
-                destination_ids=["gcs_mqtt", "s3"],  # ["s3"] ["gcs_mqtt" via mqtt]
-                merge_chunks=True,  # True for telemetry data
-                send_live=True,
-            )
-            self.logger.info(f"Ros data processed for ros_topic: {f_topic_name}")
+                # Get mission id
+                self.mission_id = self.update_mission_id()
+                self.logger.info(f"self.mission_id: {self.mission_id}")
 
-        return f
+                if f_save_locally:
+                    # Save the data locally
+                    self.logger.info(f"Saving locally for: {f_topic_name}")
+
+                    local_path = f"/var/log/vyomcloudbridge/mission_data/{self.mission_id}/{f_topic_name}"
+                    os.makedirs(os.path.dirname(local_path), exist_ok=True)
+                    with open(local_path, "a") as file:
+                        if data_type == "image":
+                            file.write(extracted_data)
+                        else:
+                            json.dump(extracted_data, file)
+
+                else:
+                    self.writer.write_message(
+                        message_data=extracted_data,  # json data
+                        filename=filename,  # nullable or epoch time
+                        data_source=f_topic_name,  # telemetry, mission_summary
+                        data_type=data_type,  # file, video, image
+                        mission_id=self.mission_id,  # mission_id
+                        priority=1,  # 1  for velocity data, battery topic, and ROS data
+                        destination_ids=["gcs_mqtt", "s3"],  # ["s3"] ["gcs_mqtt" via mqtt]
+                        merge_chunks=True,  # True for telemetry data
+                        send_live=f_send_live,
+                    )
+                self.logger.info(f"Ros data processed for ros_topic: {f_topic_name}")
+
+        return callback
 
     def import_class_from_string(self, class_string):
         """
@@ -306,15 +310,6 @@ class SendDataToServer(Node, ServiceAbstract):
 
         Returns:
             type: The class object corresponding to the given string representation.
-
-        Raises:
-            ImportError: If the module cannot be imported.
-            AttributeError: If the class cannot be found in the module.
-
-        Example:
-            >>> obj = import_class_from_string("<class 'collections.defaultdict'>")
-            >>> obj
-            <class 'collections.defaultdict'>
         """
         class_string = class_string.strip()
         if class_string.startswith("<class '") and class_string.endswith("'>"):
@@ -331,13 +326,11 @@ class SendDataToServer(Node, ServiceAbstract):
         # Import the module dynamically
         module = importlib.import_module(module_path)
 
-        # Get the class from the module
         return getattr(module, class_name)
 
     def create_dynamic_subscribers(self, f_topic):
         """
         Dynamically creates and adds a subscriber to the list of subscribers.
-
         This method takes a topic configuration, creates a subscription for the
         specified data type and topic path, and appends it to the `subscribers` list.
 
@@ -346,18 +339,14 @@ class SendDataToServer(Node, ServiceAbstract):
                 - "data_type" (str): The fully qualified class name of the data type to subscribe to.
                 - "path" (str): The topic path to subscribe to.
                 - "name" (str): The name of the topic.
-
-        Returns:
-            None
         """
-
         try:
             self.subscribers.append(
                 self.create_subscription(
                     self.import_class_from_string(f_topic["data_type"]),
                     f_topic["topic"],
                     self.create_listener_function(
-                        f_topic["data_type"], f_topic["name"], f_topic["topic"]
+                        f_topic["data_type"], f_topic["name"], f_topic["topic"], f_topic["send_live"], f_topic["frequency"], f_topic["save_locally"]
                     ),
                     self.m_qos,
                     callback_group=self.subscriber_cb_group,
@@ -388,6 +377,9 @@ class SendDataToServer(Node, ServiceAbstract):
     def stop(self):
         pass
 
+    def cleanup(self):
+        pass
+
 
 class RosPublisher(ServiceAbstract):
     def __init__(self):
@@ -431,8 +423,7 @@ class RosPublisher(ServiceAbstract):
             self.send_data_to_server.subscriber_shutdown()
             rclpy.shutdown()
             self.spin_thread.join()
-            self.logger.info("Shutdown complete.")
-            self.logger.info("RosPublisher service stopped!")
+            self.logger.info("Shutdown complete. RosPublisher service stopped!")
         except Exception as e:
             self.logger.error(f"Error in stoping RosPublisher: {str(e)}")
 
@@ -443,9 +434,6 @@ class RosPublisher(ServiceAbstract):
             self.logger.error(f"----")
 
     def is_healthy(self):
-        """
-        Check if the service is healthy. Can be overridden by subclasses.
-        """
         return self.is_running
 
     def __del__(self):
@@ -462,15 +450,12 @@ class RosPublisher(ServiceAbstract):
 def main(args=None):
     data_streamer = RosPublisher()
     try:
-        # Start the service for continuous monitoring
         data_streamer.start()
 
-        # Let it run for a short while
         time.sleep(100)
 
     finally:
         data_streamer.stop()
-
     print("Completed SendDataToServer service example")
 
 
