@@ -801,15 +801,18 @@ def setup_shell_script():
     # Shell script content
     shell_script_content = """#!/bin/bash
 # Wait for system to fully boot
-sleep 15
+sleep 10
 
 export PYTHONUNBUFFERED=1
 
 # Start all the services
 echo "Starting vyomcloudbridge services..."
 vyomcloudbridge restart
+vyomcloudbridge start mavproxyhq --system-default
+sleep 5
 vyomcloudbridge start rospublisher --system-default
 vyomcloudbridge start vyomlistener --system-default
+vyomcloudbridge start robotstat --system-default
 
 echo "All system default's services started successfully"
 
@@ -842,7 +845,7 @@ echo "vyomcloudbridge services shutting down.."
     # Shell script content
     shell_script_root_content = """#!/bin/bash
 # Wait for system to fully boot
-sleep 30
+sleep 20
 
 export PYTHONUNBUFFERED=1
 
@@ -1194,7 +1197,7 @@ def setup_log_directories():
         #
 
         # Files that need to be readable/writable by all
-        for filepath in [machine_config_file]:
+        for filepath in [machine_topics_file]:
             dirpath = os.path.dirname(filepath)
             print(f"Ensuring file exists and setting permissions: {filepath}")
             os.makedirs(dirpath, exist_ok=True)
@@ -1202,9 +1205,9 @@ def setup_log_directories():
             if not os.path.exists(filepath):
                 open(filepath, "w").close()
             os.chmod(filepath, 0o666)  # Read/write by all
-            
+
         # Other files (readable by all, writable by owner)
-        for filepath in [machine_topics_file, vyom_variables_file]:
+        for filepath in [machine_config_file, vyom_variables_file]:
             dirpath = os.path.dirname(filepath)
             print(f"Ensuring file exists and setting permissions: {filepath}")
             os.makedirs(dirpath, exist_ok=True)
