@@ -1,3 +1,4 @@
+from tracemalloc import start
 import pika
 import json
 from datetime import datetime, timezone
@@ -44,7 +45,9 @@ class MissionUtils:
         self.machine_config = Configs.get_machine_config()
         self.machine_id = self.machine_config.get("machine_id", "-") or "-"
         self.organization_id = self.machine_config.get("organization_id", "-") or "-"
-        self.data_source_name = "mission_stats"
+        self.data_source_stats = "mission_stats"
+        self.data_source_mission = "mission_message"
+        self.data_source_summary = "mission_summary"
 
     def generate_mission_id(self):
         try:
@@ -108,7 +111,7 @@ class MissionUtils:
                 - str or None: Error message if any issue occurs, else None
         """
         try:
-            if not self._ensure_connection():
+            if not self._ensure_connection() or not self.rmq_channel:
                 error_message = "Could not establish connection"
                 self.logger.error(error_message)
                 return None, error_message
@@ -142,6 +145,8 @@ class MissionUtils:
         project_id: Optional[Union[str, int]] = None,  # Project ID if available
         mission_date: Optional[str] = None,
         start_time: Optional[str] = None,
+        destination_ids: List[Union[str, int]] = ["s3"],  # array of destination_ids
+        force_start: bool = False,
     ):
         """
         Start a new mission and publish its details to RabbitMQ for VyomIQ.
@@ -158,6 +163,19 @@ class MissionUtils:
                 - dict or None: Mission details if mission is successfully started, else None
                 - str or None: Error message if any issue occurs, else None
         """
+        if destination_ids and (
+            isinstance(destination_ids, str) or isinstance(destination_ids, int)
+        ):
+            destination_ids = [str(destination_ids)]
+
+        try:
+            destination_ids = [str(x) for x in destination_ids]
+        except Exception:
+            self.logger.warning(
+                f"Invalid destination_ids, must be a list of ids[str or int]"
+            )
+            destination_ids = ["s3"]
+
         existing_mission, mission_read_error = self.get_current_mission()
         if mission_read_error is not None:
             self.logger.error(
@@ -167,17 +185,32 @@ class MissionUtils:
 
         if existing_mission is not None:
             if existing_mission.get("mission_status") == 1:
-                existing_mission_id = existing_mission.get("id")
-                error_message = f"Mission with id={existing_mission_id} is already in progress, please complete it OR mark complete before starting new mission"
-                self.logger.error(error_message)
-                return None, error_message
+                if force_start:
+                    self.logger.info(
+                        f"Force starting mission, existing mission with id={existing_mission.get('id')} will be marked completed"
+                    )
+                    mission_end_success, mission_end_error = self.end_current_mission(
+                        destination_ids=destination_ids
+                    )
+                    if not mission_end_success:
+                        self.logger.error(
+                            f"Error in marking existing mission as completed: {mission_end_error}"
+                        )
+                        return None, mission_end_error
+                else:
+                    existing_mission_id = existing_mission.get("id")
+                    error_message = f"Mission with id={existing_mission_id} is already in progress, please complete it OR mark complete before starting new mission"
+                    self.logger.error(error_message)
+                    return None, error_message
             else:
                 pass  # Existing mission already completed, so start new one
-        try:
-            project_id = int(project_id)
-        except Exception as e:
+        if project_id is not None:
+            try:
+                project_id = int(project_id)
+            except Exception:
+                project_id = None
+        else:
             project_id = None
-            pass
 
         if id is None:
             id = self.generate_mission_id()
@@ -188,7 +221,17 @@ class MissionUtils:
             )
 
         if mission_date is None:
-            mission_date = datetime.now(timezone.utc).strftime("%Y-%m-%d")
+            if start_time is None:
+                mission_date = datetime.now(timezone.utc).strftime("%Y-%m-%d")
+            else:
+                try:
+                    dt = datetime.fromisoformat(start_time)
+                    mission_date = dt.strftime("%Y-%m-%d")
+                except Exception:
+                    self.logger.warning(
+                        f"Invalid start_time: {start_time}, using today's date for mission_date"
+                    )
+                    mission_date = datetime.now(timezone.utc).strftime("%Y-%m-%d")
 
         try:
             if creator_id is None:
@@ -212,7 +255,7 @@ class MissionUtils:
                 "json_data": {},
             }
 
-            if not self._ensure_connection():
+            if not self._ensure_connection() or not self.rmq_channel:
                 error_message = "Could not establish connections, please try again"
                 return None, error_message
 
@@ -244,17 +287,18 @@ class MissionUtils:
                 organization_id=self.organization_id,
                 machine_id=self.machine_id,
                 mission_id=id,
-                data_source=self.data_source_name,
+                data_source=self.data_source_mission,
                 date=date,
                 project_id=default_project_id,
             )
 
-            message_body = json.dumps({"mission": mission_detail, "data_stats": None})
+            # message_body = json.dumps({"mission": mission_detail, "data_stats": None})
+            message_body = json.dumps(mission_detail)
             headers = {
                 "topic": f"{mission_upload_dir}/{filename}.json",
                 "message_type": "json",
-                "destination_ids": ["s3"],
-                "data_source": self.data_source_name,
+                "destination_ids": destination_ids,
+                "data_source": self.data_source_mission,
                 # meta data
                 "buffer_key": str(id),
                 "buffer_size": 0,
@@ -272,7 +316,7 @@ class MissionUtils:
             self.logger.error(error_message)
             return None, error_message
 
-    def end_current_mission(self):
+    def end_current_mission(self, destination_ids: List[Union[str, int]] = ["s3"]):
         """
         Mark the current mission as completed and update RabbitMQ.
 
@@ -282,17 +326,39 @@ class MissionUtils:
                 - error_message (str): error message if there is any error, else None in case of success
         """
         try:
+            if destination_ids and (
+                isinstance(destination_ids, str) or isinstance(destination_ids, int)
+            ):
+                destination_ids = [str(destination_ids)]
+
+            try:
+                destination_ids = [str(x) for x in destination_ids]
+            except Exception:
+                self.logger.warning(
+                    f"Invalid destination_ids, must be a list of ids[str or int]"
+                )
+                destination_ids = ["s3"]
+
             mission_detail, mission_read_error = self.get_current_mission()
             if mission_read_error is not None:
                 return False, mission_read_error
+
+            if not self._ensure_connection() or not self.rmq_channel:
+                error_message = "Could not establish connection"
+                return False, error_message
+
             if mission_detail is not None:
                 if mission_detail.get("mission_status") == 1:
-                    existing_mission_id = mission_detail.get("id")
-                    mission_detail["mission_status"] = 2
-                    if not self._ensure_connection():
-                        error_message = "Could not establish connection"
+                    existing_mission_id = mission_detail.get("id", None)
+                    if existing_mission_id is None:
+                        error_message = "Mission ID is None in the existing mission. Cannot mark it complete. Removing this object from cache."
+                        method_frame, _, _ = self.rmq_channel.basic_get(
+                            queue="current_mission", auto_ack=True
+                        )
                         return False, error_message
 
+                    mission_detail["mission_status"] = 2
+
                     while True:
                         method_frame, _, _ = self.rmq_channel.basic_get(
                             queue="current_mission", auto_ack=True
@@ -318,19 +384,20 @@ class MissionUtils:
                         organization_id=self.organization_id,
                         machine_id=self.machine_id,
                         mission_id=existing_mission_id,
-                        data_source=self.data_source_name,
+                        data_source=self.data_source_mission,
                         date=date,
                         project_id=default_project_id,
                     )
 
-                    message_body = json.dumps(
-                        {"mission": mission_detail, "data_stats": None}
-                    )
+                    # message_body = json.dumps(
+                    #     {"mission": mission_detail, "data_stats": None}
+                    # )
+                    message_body = json.dumps(mission_detail)
                     headers = {
                         "topic": f"{mission_upload_dir}/{filename}.json",
                         "message_type": "json",
-                        "destination_ids": ["s3"],
-                        "data_source": self.data_source_name,
+                        "destination_ids": destination_ids,
+                        "data_source": self.data_source_mission,
                         # meta data
                         "buffer_key": str(existing_mission_id),
                         "buffer_size": 0,
@@ -384,39 +451,92 @@ class MissionUtils:
 
 
 def main():
-    mission_stats = MissionUtils()
-
+    # Example 1: Interective start and end mission
+    mission_utils = MissionUtils()
     try:
-        success, error = mission_stats.end_current_mission()
-        if error:
-            print("Failed to end current mission:", error)
-        else:
-            print("Current mission ended successfully.")
+        try:
+            mission_start_time = datetime.now(timezone.utc).isoformat()
+            mission_detail, start_mission_error = mission_utils.start_mission(
+                start_time=mission_start_time,
+                destination_ids=["s3", "gcs_mqtt"],
+            )
+            if start_mission_error:
+                print(f"Error starting mission: {start_mission_error}")
+                # take user input, to start the current mission (this will stop the existing mission)
+                user_input = input("Try force starting the current mission? [Y/n]?")
+                if user_input.lower() == "y":
+                    force_start_mission_success, force_start_mission_error = (
+                        mission_utils.start_mission(
+                            start_time=mission_start_time,
+                            destination_ids=["s3", "gcs_mqtt"],
+                            force_start=True,
+                        )
+                    )
+                    if force_start_mission_error:
+                        raise Exception(force_start_mission_error)
+                    else:
+                        print("Mission started successfully.\n")
+                else:
+                    raise Exception(start_mission_error)
+            else:
+                print("Mission started successfully.")
+        except Exception as e:
+            raise
 
-        mission_detail, error = mission_stats.start_mission(
-            name="optional_human_readable_name",
-            description="Description of mission",
-        )
-
-        if error:
-            print("Failed to start mission:", error)
-        else:
-            print("Mission started successfully:", mission_detail)
-
-        # End the mission
-        success, error = mission_stats.end_current_mission()
-        if error:
-            print("Failed to end current mission:", error)
-        else:
-            print("Mission ended successfully.")
-    except KeyboardInterrupt:
-        print("MissionUtils service interrupted by user.")
+        # wait for the user input, "Shall we end current misssion? [Y/n]?"
+        try:
+            user_input = input("Shall we end current misssion? [Y/n]?")
+            if user_input.lower() == "y":
+                try:
+                    success, error = mission_utils.end_current_mission()
+                    if error:
+                        print("Failed to end current mission:", error)
+                    else:
+                        print("Current mission ended successfully.")
+                except KeyboardInterrupt:
+                    print("MissionUtils service interrupted by user.")
+                except Exception as e:
+                    print(f"An error in ending current mission: {str(e)}")
+                finally:
+                    mission_utils.cleanup()
+                    print("MissionUtils service cleaned up and exited.")
+            else:
+                print("Skipping marking mission as completed...")
+        except KeyboardInterrupt:
+            print("MissionUtils service interrupted by user.")
+        except Exception as e:
+            print(f"An error in ending current mission: {str(e)}")
     except Exception as e:
         print(f"An error occurred: {str(e)}")
     finally:
-        mission_stats.cleanup()
+        mission_utils.cleanup()
         print("MissionUtils service cleaned up and exited.")
 
+    # # Example 2: Non-interactive start and end mission
+    # try:
+    #     mission_utils = MissionUtils()
+    #     mission_detail, error = mission_utils.start_mission(
+    #         name="optional_human_readable_name",
+    #         description="Description of mission",
+    #     )
+    #     if error:
+    #         print("Failed to start mission:", error)
+    #     else:
+    #         print("Mission started successfully:", mission_detail)
+    #     print("Waiting for 10 seconds, before marking mission as completed...")
+    #     time.sleep(10)
+    #     # End the mission
+    #     success, error = mission_utils.end_current_mission()
+    #     if error:
+    #         print("Failed to end current mission:", error)
+    #     else:
+    #         print("Mission ended successfully.")
+    # except Exception as e:
+    #     print(f"An error occurred: {str(e)}")
+    # finally:
+    #     mission_utils.cleanup()
+    #     print("MissionUtils service cleaned up and exited.")
+
 
 if __name__ == "__main__":
     main()
